<?php
/*
 * Created by Pixel-Mafia
 * www.pixel-mafia.com
*/

# General
add_theme_support('title-tag');
add_theme_support('post-thumbnails');
add_theme_support('automatic-feed-links');
add_theme_support('post-formats', array('image', 'video', 'audio', 'quote'));

if (!isset($content_width)) {
    $content_width = 1130;
}

# Custom get_theme_mod
function photobooth_get_theme_mod($name) {
	if (func_num_args() > 1) {
		die ('The photobooth_get_theme_mod("'.$name.'") function takes only one argument. Define default values in core/customizer.php.');
	}

	global $photobooth_customizer_default_values;

	if (!isset($photobooth_customizer_default_values[$name])) {
		die ('Error! You did not add the default value for the "'.$name.'" option! core/customizer.php.');
	}
	return get_theme_mod($name, $photobooth_customizer_default_values[$name]);
}

# ADD Localization Folder
add_action('after_setup_theme', 'photobooth_pomo');
function photobooth_pomo()
{
    load_theme_textdomain('photobooth', get_template_directory() . '/languages');
}

require_once(get_template_directory() . "/core/init.php");

# Admin Ajax
add_action('admin_head', 'photobooth_admin_ajax_url');
function photobooth_admin_ajax_url() {
    echo "
    <script>
        var photobooth_admin_ajax_url = '" . admin_url("admin-ajax.php") . "';
    </script>
    ";
}

# ADD Theme Settings Page
add_action('admin_menu', 'photobooth_add_menu');
function photobooth_add_menu()
{
    add_theme_page('Photobooth', 'Photobooth', 'administrator', 'photobooth_settings_page', 'photobooth_theme_settings_page' );
}

# Show Admin Settings Page
function photobooth_theme_settings_page()
{
    if (!current_user_can('manage_options')) {
        wp_die(esc_html__('You do not have permissions to access this page.', 'photobooth'));
    }
	echo '
    <div class="photobooth_admin_wrapper">
    	<h1>Hey!</h1>
	    <p>All settings of our theme are made through a standard Customizer. Click <a href="'.get_admin_url(null, 'customize.php').'">here</a> to go to the settings.</p>

		<p>If you want to reset all settings, feel free to click on <a href="#" class="photobooth_reset_all_settings">this link</a>. But remember that there is no turning back ;)</p>

		<p>If you have any questions, problems or want to talk - email us via the form on <a href="http://themeforest.net/user/pixel-mafia" target="_blank">this</a> page.</p>
    </div>
    ';
}

# Register CSS/JS
add_action('wp_enqueue_scripts', 'photobooth_css_js');
if (!function_exists('photobooth_css_js')) {
    function photobooth_css_js()
    {
        # CSS
        wp_enqueue_style('bootstrap', get_template_directory_uri() . '/css/bootstrap.min.css');
        wp_enqueue_style('font-awesome', get_template_directory_uri() . '/css/font-awesome.min.css');
        wp_enqueue_style('photobooth-vc', get_template_directory_uri() . '/css/vc.css');
        wp_enqueue_style('photobooth-theme', get_template_directory_uri() . '/css/theme.css');
		wp_enqueue_style('photobooth-responsive', get_template_directory_uri() . '/css/responsive.css');
		if (get_post_type() == 'albums') {
			wp_enqueue_style('photobooth-swipebox', get_template_directory_uri() . '/css/swipebox.css');
		}
        if (get_page_template_slug() == 'page-split-showcase.php') {
            wp_enqueue_style('photobooth-swipebox', get_template_directory_uri() . '/css/swipebox.css');
        }
		if (photobooth_is_woocommerce_activated()) {
			wp_enqueue_style('photobooth-woocommerce', get_template_directory_uri() . '/css/woocommerce.css');
		}

        # JS
        wp_enqueue_script('photobooth-theme', get_template_directory_uri() . '/js/theme.js', array('jquery'), false, true);
		if (get_post_type() == 'albums') {
			wp_enqueue_script('jquery_swipebox', get_template_directory_uri() . '/js/jquery.swipebox.js', true, false, true);
		}
        if (get_page_template_slug() == 'page-split-showcase.php') {
            wp_enqueue_script('jquery_swipebox', get_template_directory_uri() . '/js/jquery.swipebox.js', true, false, true);
            wp_enqueue_script('mousewheel_js', get_template_directory_uri() . '/js/jquery.mousewheel.js', array(), false, true);
            wp_enqueue_script('photobooth-split-showcase', get_template_directory_uri() . '/js/split_showcase.js', array('jquery'), false, true);
        }
        if (get_page_template_slug() == 'page-fullscreen-slider.php') {
            wp_enqueue_script('photobooth-fullscreen-slideshow', get_template_directory_uri() . '/js/slideshow_gallery.js', array('jquery'), false, true);
            wp_enqueue_script('jquery-event-swipe', get_template_directory_uri() . '/js/jquery.event.swipe.js', array('jquery'), false, true);
        }
        if (get_page_template_slug() == 'page-ribbon-slider.php') {
            wp_enqueue_script('photobooth-ribbon-slider', get_template_directory_uri() . '/js/ribbon_slider.js', array('jquery'), false, true);
            wp_enqueue_script('jquery-event-swipe', get_template_directory_uri() . '/js/jquery.event.swipe.js', array('jquery'), false, true);
        }
		if (get_page_template_slug() == 'page-albums-slider.php') {
			wp_enqueue_script('jquery_albums_slider', get_template_directory_uri() . '/js/jquery_albums_slider.js', true, false, true);
			wp_enqueue_script('jquery-event-swipe', get_template_directory_uri() . '/js/jquery.event.swipe.js', array('jquery'), false, true);
		}
		if (photobooth_is_woocommerce_activated()) {
			wp_enqueue_script('photobooth-woocommerce', get_template_directory_uri() . '/js/woocommerce.js', array('jquery'), false, true);
		}

    }
}

# Register CSS/JS for Admin Settings
add_action('admin_enqueue_scripts', 'photobooth_admin_css_js');
if (!function_exists('photobooth_admin_css_js')) {
    function photobooth_admin_css_js()
    {
        # CSS
        wp_enqueue_style('font-awesome', get_template_directory_uri() . '/css/font-awesome.min.css');
        wp_enqueue_style('photobooth-admin', get_template_directory_uri() . '/css/admin.css');
        # JS
        wp_enqueue_script('photobooth-admin', get_template_directory_uri() . '/js/admin.js', array('jquery', 'jquery-ui-core', 'jquery-ui-sortable'), false, true);
    }
}

# WP Footer
add_action('wp_footer', 'photobooth_wp_footer');
function photobooth_wp_footer()
{
    photoboothHelper::getInstance()->echoFooter();
}

# Register Menu
add_action('init', 'photobooth_register_menu');
function photobooth_register_menu()
{
    register_nav_menus(
        array(
            'main' => esc_attr__('Main menu', 'photobooth')
        )
    );
}

# Logo
function photobooth_the_logo($position = 'header')
{
    if ($position == 'header') {
        $prefix = '';
    }
    if ($position == 'footer') {
        $prefix = 'footer_';
    }
    if (photobooth_get_theme_mod($prefix . 'logo_type') == 'image_logo') {
        echo '<a href="' . esc_url(home_url('/')) . '" class="photobooth_image_logo ' . (photobooth_get_theme_mod($prefix . 'logo_retina') == true ? 'photobooth_retina' : '') . '"></a>';
    } else {
        echo '<div class="photobooth_text_logo"><a href="' . esc_url(home_url('/')) . '">' . photobooth_get_theme_mod($prefix . 'logo_text_caption') . '</a></div>';
    }
}

# Hex 2 RGB
function photobooth_hex2rgb($hex)
{
    $hex = str_replace("#", "", $hex);

    if (strlen($hex) == 3) {
        $r = hexdec(substr($hex, 0, 1) . substr($hex, 0, 1));
        $g = hexdec(substr($hex, 1, 1) . substr($hex, 1, 1));
        $b = hexdec(substr($hex, 2, 1) . substr($hex, 2, 1));
    } else {
        $r = hexdec(substr($hex, 0, 2));
        $g = hexdec(substr($hex, 2, 2));
        $b = hexdec(substr($hex, 4, 2));
    }
    return $r . "," . $g . "," . $b;
}

# Register Sidebars
add_action('widgets_init', 'photobooth_widgets_init');
function photobooth_widgets_init()
{
    register_sidebar(
        array(
            'name' => esc_attr__('Sidebar', 'photobooth'),
            'id' => 'sidebar',
            'description' => esc_attr__('Widgets in this area will be shown on all posts and pages.', 'photobooth'),
            'before_widget' => '<div id="%1$s" class="widget %2$s">',
            'after_widget' => '</div>',
            'before_title' => '<h6 class="widgettitle">',
            'after_title' => '</h6>',
        )
    );

    register_sidebar(
        array(
            'name' => esc_attr__('Footer Sidebar', 'photobooth'),
            'id' => 'footer',
            'description' => esc_attr__('Widgets in this area will be shown on all posts and pages.', 'photobooth'),
            'before_widget' => '<div id="%1$s" class="col-md-' . (photobooth_get_theme_mod('footer_widgets_in_row') == '4' ? '3' : '4') . ' col-sm-6 col-xs-12 widget %2$s">',
            'after_widget' => '</div>',
            'before_title' => '<h6 class="widgettitle">',
            'after_title' => '</h6>',
        )
    );

    if (photobooth_is_woocommerce_activated()) {
        register_sidebar(
            array(
                'name' => esc_attr__('Sidebar Woocommerce', 'photobooth'),
                'id' => 'sidebar-woocommerce',
                'description' => esc_attr__('Widgets in this area will be shown on Woocommerce Pages.', 'photobooth'),
                'before_widget' => '<div id="%1$s" class="widget woocommerce_widget %2$s">',
                'after_widget' => '</div>',
                'before_title' => '<h6 class="widgettitle"><span>',
                'after_title' => '</span></h6>',
            )
        );
    }
}

# Post Formats
function photobooth_get_post_formats($args = array())
{
    if (photobooth_post_options()) {
        $html = '';
        if (!empty($args)) {
            extract($args);
            if (isset($output_template) && $output_template == 'blog_grid') {
                $grid_ratio = $grid_img_height / $grid_img_width;
            }
        }


        $html .= '<div class="photobooth_post_formats photobooth_pf_' . get_post_format() . '">';
        if (get_post_format() == 'image') {
            if (is_array(photobooth_get_post_option('photobooth_pf_images'))) {
                # CSS
                wp_enqueue_style('owl-carousel', get_template_directory_uri() . '/css/owl.carousel.css');
                # JS
                wp_enqueue_script('owl-carousel', get_template_directory_uri() . '/js/owl.carousel.min.js', array('jquery'), false, true);

                $html .= '<div class="photobooth_owlCarousel owl-carousel owl-theme">';
                foreach (photobooth_get_post_option('photobooth_pf_images') as $key => $image) {
                    if (isset($output_template) && $output_template == 'blog_grid') {
                        $html .= '<div class="item"><img src="' . aq_resize($image['full_url'], $grid_img_width, $grid_img_height, true, true, true) . '" alt="' . $image['alt'] . '"></div>';
                    } else {
                        if (photobooth_get_post_option('photobooth_pf_images_crop_status', 'yes') == 'yes') {
                            $html .= '<div class="item"><img src="' . aq_resize($image['full_url'], photobooth_get_post_option('photobooth_pf_images_width', '1600'), photobooth_get_post_option('photobooth_pf_images_height', '900'), true, true, true) . '" alt="' . $image['alt'] . '"></div>';
                        } else {
                            $html .= '<div><img src="' . $image['full_url'] . '" alt="' . $image['alt'] . '"></div>';
                        }
                    }
                }
                $html .= '</div>';

                photoboothHelper::getInstance()->addJSToFooter('owl_post_formats', '
                    jQuery(".photobooth_owlCarousel").on("initialized.owl.carousel", function(e) {
						jQuery(".photobooth_owlCarousel").css("opacity", "1");
					});
					jQuery(".photobooth_owlCarousel").owlCarousel(
                        {
                            items:1,
						    lazyLoad:true,
							loop:true,
							autoplay:false,
							autoplayTimeout:5000,
							autoplayHoverPause:true,
							autoHeight:true
                        }
                    );
                ');
            } else {
                if (isset($output_template) && $output_template == 'blog_grid') {
					$html .= '<img class="photobooth_stand_fi" data-width="'. $grid_img_width .'" src="' . aq_resize(photobooth_get_featured_image_url(), $grid_img_width, $grid_img_height, true, true, true) . '" alt="'. get_the_title() .'">';
                } else {
                    $html .= '<img class="photobooth_stand_fi" src="' . aq_resize(photobooth_get_featured_image_url(), 300, 300) . '" alt="'. get_the_title() .'">';
                }
            }
        }

        if (get_post_format() == 'video') {
            if (isset($output_template) && $output_template == 'blog_grid') {
                $html .= '<div class="photobooth_pf_video_cont photobooth_blog_grid_ratio" data-ratio="' . esc_attr($grid_ratio) . '">' . photobooth_get_post_option('photobooth_pf_video_url') . '</div>';
            } else {
                $html .= '<div class="photobooth_pf_video_cont" style="height:' . photobooth_get_post_option('photobooth_pf_video_height', '500') . 'px;">' . photobooth_get_post_option('photobooth_pf_video_url') . '</div>';
            }
        }
        if (get_post_format() == 'audio') {
            if (isset($output_template) && $output_template == 'blog_grid') {
                $html .= '<div class="photobooth_pf_audio_cont photobooth_blog_grid_ratio" data-ratio="' . esc_attr($grid_ratio) . '">' . photobooth_get_post_option('photobooth_pf_audio_url') . '</div>';
            } else {
                $html .= '<div class="photobooth_pf_audio_cont">' . photobooth_get_post_option('photobooth_pf_audio_url') . '</div>';
            }
        }
        if (get_post_format() == 'quote') {
            if (isset($output_template) && $output_template == 'blog_grid') {
                $html .= '<div class="photobooth_pf_quote photobooth_blog_grid_ratio" data-ratio="' . esc_attr($grid_ratio) . '"><div class="photobooth_pf_quote_cont"><h5 class="photobooth_pf_quote_text">' . photobooth_get_post_option('photobooth_pf_quote_text') . '</h5><div class="photobooth_pf_quote_author">' . photobooth_get_post_option('photobooth_pf_quote_author') . '</div></div></div>';
            } else {
                $html .= '<div class="photobooth_pf_quote"><div class="photobooth_pf_quote_cont"><h5 class="photobooth_pf_quote_text">' . photobooth_get_post_option('photobooth_pf_quote_text') . '</h5><div class="photobooth_pf_quote_author">' . photobooth_get_post_option('photobooth_pf_quote_author') . '</div></div></div>';
            }
        }
        if (get_post_format() == '' && photobooth_get_featured_image_url()) {
			if (isset($output_template) && $output_template == 'blog_grid') {
            	$html .= '<img class="photobooth_stand_fi" src="' . aq_resize(photobooth_get_featured_image_url(), $grid_img_width, $grid_img_height, true, true, true) . '" alt="'. get_the_title() .'">';
			} else {
				$html .= '<img class="photobooth_stand_fi" src="' . photobooth_get_featured_image_url() . '" alt="'. get_the_title() .'">';
			}
        }

        $html .= '</div>';
        return $html;
    } else {
        return '<div class="photobooth_post_formats">'.(photobooth_get_featured_image_url() ? '<img class="photobooth_stand_fi" src="' . photobooth_get_featured_image_url() . '" alt="'. get_the_title() .'">' : '').'</div>';
    }
}

# RWMB check
function photobooth_post_options()
{
    if (class_exists('RWMB_Loader')) {
        return true;
    } else {
        return false;
    }
}

# RWMB get option
function photobooth_get_post_option($name, $default = false)
{
    if (class_exists('RWMB_Loader')) {
        if (rwmb_meta($name)) {
            return rwmb_meta($name);
        } else {
            return $default;
        }
    } else {
        return $default;
    }
}

# Get Preffered Option
function photobooth_get_prefered_option($name)
{
	if (func_num_args() > 1) {
		die ('The photobooth_get_prefered_option("'.$name.'") function may takes only one argument.');
	}

	global $photobooth_customizer_default_values;

	if (!isset($photobooth_customizer_default_values[$name])) {
		die ('Error! You did not add the default value for the "'.$name.'" option! core/customizer.php.');
	}

    if (photobooth_get_post_option($name) && photobooth_get_post_option($name) !== 'default') {
        return photobooth_get_post_option($name, $photobooth_customizer_default_values[$name]);
    } else {
        return photobooth_get_theme_mod($name);
    }
}

# Previous and Next Posts
function photobooth_prev_next_posts()
{
    $prev_post = get_previous_post();
    $next_post = get_next_post();

    if (empty($prev_post) && empty($next_post)) {
        return;
    }

    global $post;

    echo '
        <div class="photobooth_prev_next_posts">
            <div class="row">
    ';

    echo '<div class="col-md-6 photobooth_prev_post">';

    if (!empty($prev_post)) {
        $post = get_post($prev_post->ID);
        setup_postdata($post);

        echo '
                    <div class="innerpadding">
                        <a class="photobooth_prev_post_link" href="' . get_comments_link() . '"></a>
                        <a class="notextdecor photobooth_post_title" href="' . get_permalink() . '">
                            <h5 class="innertitle">' . get_the_title() . '</h5>
                        </a>
                        <div class="photobooth_meta">
                            <div>' . get_the_date() . '</div>
                            <div>' . esc_attr__('by', 'photobooth') . ' ' . get_the_author_posts_link() . '</div>
                            <div>
                                <a href="' . get_comments_link() . '">' . esc_attr__('Comments', 'photobooth') . ': ' . get_comments_number() . '</a>
                            </div>
                        </div>
                    </div>
                ';

        wp_reset_postdata();
    }

    echo '</div>';
    echo '<div class="col-md-6 photobooth_next_post">';

    if (!empty($next_post)) {
        $post = get_post($next_post->ID);
        setup_postdata($post);

        echo '

                    <div class="innerpadding">
                        <a class="photobooth_next_post_link" href="' . get_comments_link() . '"></a>
                        <a class="notextdecor photobooth_post_title" href="' . get_permalink() . '">
                            <h5 class="innertitle">' . get_the_title() . '</h5>
                        </a>
                        <div class="photobooth_meta">
                            <div>' . get_the_date() . '</div>
                            <div>' . esc_attr__('by', 'photobooth') . ' ' . get_the_author_posts_link() . '</div>
                            <div>
                                <a href="' . get_comments_link() . '">' . esc_attr__('Comments', 'photobooth') . ': ' . get_comments_number() . '</a>
                            </div>
                        </div>
                    </div>
                ';

        wp_reset_postdata();
    }

    echo '
                </div>
            </div>
        </div>
    ';
}

# Get Featured Image Url
function photobooth_get_featured_image_url()
{
    $featured_image_full_url = wp_get_attachment_image_src(get_post_thumbnail_id(), 'full');
    if (isset($featured_image_full_url[0]) && strlen($featured_image_full_url[0]) > 0) {
        return $featured_image_full_url[0];
    } else {
        return false;
    }
}

# Featured Posts
function photobooth_featured_posts($args = array('orderby' => 'rand', 'numberposts' => '2', 'featured_image' => 'show', 'excerpt' => 'show', 'post_meta' => 'show'))
{
    extract($args);

    if (photobooth_get_prefered_option('featured_posts_status') == 'enabled') {

        $args = array(
            'post_type' => 'post',
            'post_status' => 'publish',
            'ignore_sticky_posts' => 1,
            'orderby' => esc_attr($orderby),
            'posts_per_page' => absint($numberposts),
        );

        query_posts($args);

        if (have_posts()) {

            echo '<h3 class="photobooth_tac">' . esc_attr__('You May Also Like', 'photobooth') . '</h3>';
            echo '<div class="row photobooth_featured_posts">';

            while (have_posts()) {
                the_post();
                ?>

                <div class="col-md-<?php echo(12 / $numberposts); ?>">
                    <?php if (photobooth_get_featured_image_url() && $featured_image == 'show') { ?>
                        <a href="<?php the_permalink(); ?>" class="photobooth_fimage photobooth_image_fader">
                            <img
                                src="<?php echo aq_resize(photobooth_get_featured_image_url(), 800, 600, true, true, true); ?>"
                                alt="<?php the_title(); ?>">
                        </a>
                    <?php } ?>
                    <a class="notextdecor photobooth_post_title" href="<?php the_permalink(); ?>">
                        <h5 class="innertitle"><?php the_title(); ?></h5>
                    </a>

                    <?php if ($post_meta == 'show') { ?>
                        <div class="photobooth_meta">
                            <div><?php echo get_the_date(); ?></div>
                            <div><?php echo esc_attr__('by', 'photobooth');
                                echo ' ';
                                the_author_posts_link(); ?></div>
                            <div><?php echo esc_attr__('in', 'photobooth');
                                echo ' ';
                                the_category(', '); ?></div>
                        </div>
                    <?php } ?>

                    <?php if ($excerpt == 'show') { ?>
                        <div class="photobooth_excerpt">
                            <?php the_excerpt(); ?>
                        </div>
                    <?php } ?>
                </div>
                <?php
            }
            wp_reset_query();

            echo '</div>';
        }
    }
}

# Featured Albums
function photobooth_featured_albums($args = array('orderby' => 'rand', 'numberposts' => '2', 'featured_image' => 'show'))
{
    extract($args);

    if (photobooth_get_prefered_option('featured_posts_status') == 'enabled') {

        $args = array(
            'post_type' => 'albums',
            'post_status' => 'publish',
            'orderby' => esc_attr($orderby),
            'posts_per_page' => absint($numberposts),
        );

        query_posts($args);

        if (have_posts()) {

            echo '<h3 class="photobooth_tac photobooth_tac_albums">' . esc_attr__('You May Also Like', 'photobooth') . '</h3>';
            echo '<div class="row photobooth_featured_albums">';

            while (have_posts()) {
                the_post();
                ?>

                <div class="photobooth_featured_albums_col col-md-<?php echo(12 / $numberposts); ?>">
                	<div class="photobooth_featured_albums_item">
						<?php if (photobooth_get_featured_image_url() && $featured_image == 'show') { ?>
                            <a href="<?php the_permalink(); ?>" class="photobooth_featured_albums_image photobooth_image_fader">
                                <img
                                    src="<?php echo aq_resize(photobooth_get_featured_image_url(), 915, 600, true, true, true); ?>"
                                    alt="<?php the_title(); ?>">
                            </a>
                        <?php }
							$galCateg = '';
							$new_term_list = get_the_terms(get_the_id(), "albumscat");
							if (is_array($new_term_list)) {
								foreach ($new_term_list as $term) {
									$tempname = strtr($term->name, array(
										' ' => '-',
									));
									$galCateg .= $tempname . " / ";
								}
							} else {
								$galCateg = 'Uncategorized  ';
							}
							$galCateg = substr($galCateg, 0, -2);
						?>
                        <div class="photobooth_features_albums_content">
                            <a class="photobooth_features_albums_title" href="<?php the_permalink(); ?>">
                                <h5 class="innertitle"><?php the_title(); ?></h5>
                            </a>
                            <div class="photobooth_featured_albums_meta">
                            	<?php echo photobooth_output($galCateg); ?>
                            </div>
                        </div>
                    </div>
                </div>
                <?php
            }
            wp_reset_query();

            echo '</div>';
        }
    }
}

# Transparent Header Check
function photobooth_transparent_header_check()
{
    if (is_404()) {
		    photoboothHelper::getInstance()->addJSToFooter('non_transp_head', '
		        jQuery("html").addClass("photobooth_non_transparent_header");
		    ');
        } elseif (get_post_type(get_the_ID()) == 'albums' && is_single()) {
	        photoboothHelper::getInstance()->addJSToFooter('transp_head', '
		        jQuery("html").addClass("photobooth_transparent_header");
		    ');
	    } else {
			if (photobooth_get_prefered_option('header_transparent') == 'enabled') {
				photoboothHelper::getInstance()->addJSToFooter('transp_head', '
				jQuery("html").addClass("photobooth_transparent_header");
			');
        }
    }
}

# VC Init
add_action('vc_before_init', 'photobooth_vc_before_init_actions');
function photobooth_vc_before_init_actions()
{
    setcookie('vchideactivationmsg', '1', strtotime('+3 years'), '/');
    setcookie('vchideactivationmsg_vc11', (defined('WPB_VC_VERSION') ? WPB_VC_VERSION : '1'), strtotime('+3 years'), '/');
    vc_set_as_theme();

    require_once(get_template_directory() . '/core/vc-elements/blog/blog.php');
    require_once(get_template_directory() . '/core/vc-elements/blog_grid/blog_grid.php');
    require_once(get_template_directory() . '/core/vc-elements/countdown/countdown.php');
    require_once(get_template_directory() . '/core/vc-elements/grid_gallery/grid_gallery.php');
    require_once(get_template_directory() . '/core/vc-elements/image_carousel/image_carousel.php');
    require_once(get_template_directory() . '/core/vc-elements/price_table/price_table.php');
    require_once(get_template_directory() . '/core/vc-elements/testimonials/testimonials.php');
    require_once(get_template_directory() . '/core/vc-elements/works_slider/works_slider.php');
    require_once(get_template_directory() . '/core/vc-elements/promo_text/promo_text.php');
    require_once(get_template_directory() . '/core/vc-elements/stripes/stripes.php');
    require_once(get_template_directory() . '/core/vc-elements/simple_slider/simple_slider.php');
}

# PRE
function photobooth_pre($array)
{
    echo '<pre>';
    print_r($array);
    echo '</pre>';
}

# Get Image Meta
function photobooth_get_attachment($attachment_id)
{
    $attachment = get_post($attachment_id);
    return array(
        'alt' => get_post_meta($attachment->ID, '_wp_attachment_image_alt', true),
        'caption' => $attachment->post_excerpt,
        'description' => $attachment->post_content,
        'href' => get_permalink($attachment->ID),
        'src' => $attachment->guid,
        'title' => $attachment->post_title
    );
}

add_filter('admin_footer', 'photobooth_admin_footer');
function photobooth_admin_footer()
{
	if (strlen(get_page_template_slug())>0) {
	    echo "<input type='hidden' name='' value='" . (get_page_template_slug() ? get_page_template_slug() : '') . "' class='photobooth_this_template_file'>";
    }
}

# WP_Head
add_action('wp_head', 'photobooth_wp_head');
function photobooth_wp_head()
{
    echo "
    <script type='text/javascript'>
    var photobooth_ajaxurl = '" . admin_url('admin-ajax.php') . "';
    </script>";

    echo (strlen(photobooth_get_theme_mod('photobooth_code_before_head_val')) > 0 ? photobooth_get_theme_mod('photobooth_code_before_head_val') : '');
}

# Admin_Head
add_action('admin_head', 'photobooth_admin_head');
function photobooth_admin_head()
{
    echo "
    <script type='text/javascript'>
    var photobooth_themeurl = '" . esc_url(get_template_directory_uri()) . "';
    </script>";
}

# Tiny Dropcap Button
add_editor_style('css/core/pm_tiny.css');
add_action('init', 'photobooth_tiny');
function photobooth_tiny()
{
    if (current_user_can('edit_posts') && current_user_can('edit_pages')) {
        add_filter('mce_external_plugins', 'photobooth_tiny_plugin');
        add_filter('mce_buttons', 'photobooth_tiny_register_button');
    }
}

function photobooth_tiny_plugin($plugin_array)
{
    $plugin_array['photobooth_tiny'] = esc_url(get_template_directory_uri()) . '/js/core/pm_tiny.js';
    return $plugin_array;
}

function photobooth_tiny_register_button($buttons)
{
    array_push($buttons, "photobooth_dropcap");
    return $buttons;
}

add_filter('mce_buttons_2', 'photobooth_mce_buttons_2');
function photobooth_mce_buttons_2($buttons)
{
    array_push($buttons, 'backcolor');
    return $buttons;
}

add_filter('preview_post_link', 'photobooth_remove_post_format_parameter', 9999);
function photobooth_remove_post_format_parameter($url) {
    $url = remove_query_arg('post_format', $url);
    return $url;
}

add_filter('wp_list_categories', 'photobooth_category_filter');
function photobooth_category_filter($links) {
  $links = str_replace('</a> (', ' (', $links);
  $links = str_replace(')', ')</a>', $links);
  return $links;
}

# Object to array
function photobooth_objectToArray($object) {
    if(!is_object($object) && !is_array($object))
        return $object;

    return array_map('photobooth_objectToArray', (array) $object);
}

# Customizer Preview
function photobooth_preview_customizer() {
	# update_option('pm_demo', 'true');
	if (get_option('pm_demo') == 'true') {
	?>
	<div class="photobooth_preview_customizer_cont photobooth_preview_customizer_nl">
		<a href="http://pixel-mafia.com/demo/wordpress-themes/photobooth/wp-admin/customize.php"><i class="fa fa-cog" aria-hidden="true"></i></a>
	</div>
	<?php
	}
}

/* Social Icons */
if (!function_exists('photobooth_show_social_icons')) {
	function photobooth_show_social_icons($array)
	{
		$compile = "";
		$compile .= '
			<div class="photobooth_social_icons"><ul class="photobooth_social_icons_list">';

		foreach ($array as $key => $value) {
			if (strlen(photobooth_get_theme_mod($value['uniqid'])) > 0) {
				$compile .= "<li><a class='" . $value['class'] . "' target='" . $value['target'] . "' href='" . photobooth_get_theme_mod($value['uniqid']) . "' title='" . $value['title'] . "'><i class='fa fa-" . $value['class'] . "'></i></a></li>";
			}
		}
		$compile .= "</ul></div>";
		if (is_array($array) && count($array) > 0) {
			return $compile;
		} else {
			return "";
		}
	}
}
# Activate Visual Composer for Custom Post Types
$list = array(
    'page',
	'post',
	'albums'
);
if (function_exists('vc_set_default_editor_post_types')) {
	vc_set_default_editor_post_types($list);
}

function photobooth_add_template_slug_to_body( $classes ) {
	$templateName = basename(get_page_template_slug(get_the_ID()));
	$templateName = str_ireplace('template-', '', basename(get_page_template_slug(get_the_ID()), '.php'));

	$pf = get_post_format(get_the_ID());
	$post_type = get_post_format(get_the_ID());
	$post_type_class = '';

	if (!empty($post_type)) {
		$post_type_class = ' post-type-' . get_post_format();
	}

    return $classes . $templateName . $post_type_class;
}
add_filter('admin_body_class', 'photobooth_add_template_slug_to_body');

if (!function_exists( 'photobooth_is_woocommerce_activated')) {
	function photobooth_is_woocommerce_activated() {
		return class_exists( 'WooCommerce' ) ? true : false;
	}
}

if (photobooth_is_woocommerce_activated()) {
    add_action('customize_register', 'photobooth_shop_customizer_register');
    function photobooth_shop_customizer_register($wp_customize) {
        global $photobooth_customizer_default_values;

        $wp_customize->add_section('photobooth_shop_settings',
            array(
                'title' => esc_attr__('Photobooth Shop Settings', 'photobooth'),
                'panel' => 'woocommerce',
            )
        );
        $wp_customize->add_section('photobooth_shop_colors',
            array(
                'title' => esc_attr__('Additional Shop Colors', 'photobooth'),
                'panel' => 'woocommerce',
            )
        );

        # Sidebar Position
        $wp_setting_name = 'shop_sidebar_position';
        $wp_customize->add_setting($wp_setting_name, array('default' => $photobooth_customizer_default_values[$wp_setting_name], 'sanitize_callback'	=> 'esc_attr'));
        $wp_customize->add_control(new WP_Customize_Control(
            $wp_customize,
            $wp_setting_name,
            array(
                'label' => esc_attr__('Sidebar Position', 'photobooth'),
                'section' => 'photobooth_shop_settings',
                'settings' => $wp_setting_name,
                'type' => 'select',
                'choices' => array('photobooth_left_sidebar' => 'Left', 'photobooth_right_sidebar' => 'Right', 'photobooth_no_sidebar' => 'None'),
            )
        ));

        # Sale Label
        $wp_setting_name = 'shop_sale_label';
        $wp_customize->add_setting($wp_setting_name, array('default' => $photobooth_customizer_default_values[$wp_setting_name], 'sanitize_callback'	=> 'esc_attr'));
        $wp_customize->add_control(new WP_Customize_Control(
            $wp_customize,
            $wp_setting_name,
            array(
                'label' => esc_attr__('Sale Label State', 'photobooth'),
                'section' => 'photobooth_shop_settings',
                'settings' => $wp_setting_name,
                'type' => 'select',
                'choices' => array('on' => 'On', 'off' => 'Off'),
            )
        ));

        # Header Cart
        $wp_setting_name = 'cart_in_header';
        $wp_customize->add_setting($wp_setting_name, array('default' => $photobooth_customizer_default_values[$wp_setting_name], 'sanitize_callback'	=> 'esc_attr'));
        $wp_customize->add_control(new WP_Customize_Control(
            $wp_customize,
            $wp_setting_name,
            array(
                'label' => esc_attr__('Cart Icon in Header', 'photobooth'),
                'section' => 'photobooth_shop_settings',
                'settings' => $wp_setting_name,
                'type' => 'select',
                'choices' => array('show' => 'Show', ' hide' => 'Hide'),
            )
        ));

        # Product Lightbox
        $wp_setting_name = 'shop_lightbox';
        $wp_customize->add_setting($wp_setting_name, array('default' => $photobooth_customizer_default_values[$wp_setting_name], 'sanitize_callback'	=> 'esc_attr'));
        $wp_customize->add_control(new WP_Customize_Control(
            $wp_customize,
            $wp_setting_name,
            array(
                'label' => esc_attr__('Single Product Image Lightbox', 'photobooth'),
                'section' => 'photobooth_shop_settings',
                'settings' => $wp_setting_name,
                'type' => 'select',
                'choices' => array('on' => 'On', 'off' => 'Off'),
            )
        ));

        # Product Zoom
        $wp_setting_name = 'shop_zoom';
        $wp_customize->add_setting($wp_setting_name, array('default' => $photobooth_customizer_default_values[$wp_setting_name], 'sanitize_callback'	=> 'esc_attr'));
        $wp_customize->add_control(new WP_Customize_Control(
            $wp_customize,
            $wp_setting_name,
            array(
                'label' => esc_attr__('Single Product Image Zoom', 'photobooth'),
                'section' => 'photobooth_shop_settings',
                'settings' => $wp_setting_name,
                'type' => 'select',
                'choices' => array('on' => 'On', 'off' => 'Off'),
            )
        ));

        # Product Slider
        $wp_setting_name = 'shop_slider';
        $wp_customize->add_setting($wp_setting_name, array('default' => $photobooth_customizer_default_values[$wp_setting_name], 'sanitize_callback'	=> 'esc_attr'));
        $wp_customize->add_control(new WP_Customize_Control(
            $wp_customize,
            $wp_setting_name,
            array(
                'label' => esc_attr__('Single Product Image Slider', 'photobooth'),
                'section' => 'photobooth_shop_settings',
                'settings' => $wp_setting_name,
                'type' => 'select',
                'choices' => array('on' => 'On', 'off' => 'Off'),
            )
        ));
    }
}

if (class_exists('WooCommerce')) {
    add_theme_support( 'woocommerce', array(
        'thumbnail_image_width' => 500,
        'thumbnail_image_height' => 500,
        'single_image_width'    => 640,
        'product_grid'          => array(
            'default_rows'    => 3,
            'min_rows'        => 2,
            'max_rows'        => 8,
            'default_columns' => 3,
            'min_columns'     => 2,
            'max_columns'     => 5,
        ),
    ));
    if (photobooth_get_theme_mod('shop_zoom') == 'on') {
        add_theme_support( 'wc-product-gallery-zoom' );
    }
    if (photobooth_get_theme_mod('shop_lightbox') == 'on') {
        add_theme_support( 'wc-product-gallery-lightbox' );
    }
    if (photobooth_get_theme_mod('shop_slider') == 'on') {
        add_theme_support( 'wc-product-gallery-slider' );
    }
}

if (function_exists('photobooth_add_widget'))
{
	add_action('widgets_init', 'photobooth_widgets_activate');
	if (!function_exists('photobooth_widgets_activate'))
	{
		function photobooth_widgets_activate() {
			photobooth_add_widget('photoboothGalleryPosts');
			photobooth_add_widget('photoboothFeaturedPosts');
			photobooth_add_widget('photoboothTextTable');
		}
	}
}

if (!function_exists('photobooth_output')) {
    function photobooth_output($code) {
        return $code;
    }
}

function update_woocommerce_version() {
  if(class_exists('WooCommerce')) {
    global $woocommerce;

    if(version_compare(get_option('woocommerce_db_version', null), $woocommerce->version, '!=')) {
      update_option('woocommerce_db_version', $woocommerce->version);

      if(! wc_update_product_lookup_tables_is_running()) {
        wc_update_product_lookup_tables();
      }
    }
  }
}
add_action('init', 'update_woocommerce_version');
